@@ -10,19 +10,16 @@
 #include "square.h"
 #include "util.h"
 
-// constants
+// defines
 
-const int Empty = 0;
-
-const int FlagsNone = 0;
-const int FlagsWhiteKingCastle  = 1 << 0;
-const int FlagsWhiteQueenCastle = 1 << 1;
-const int FlagsBlackKingCastle  = 1 << 2;
-const int FlagsBlackQueenCastle = 1 << 3;
+#define Empty  0
+#define SideH  0
+#define SideA  1
+#define SideNb 2
 
 // types
 
-struct board_t {
+typedef struct {
 
    uint8 square[SquareNb];
    sint8 pos[SquareNb];
@@ -33,14 +30,14 @@ struct board_t {
    sint8 number[12];
 
    sint8 turn;
-   sint8 flags;
+   uint8 castle[ColourNb][SideNb];
    uint8 ep_square;
 
    sint16 ply_nb;
    sint16 move_nb;
 
    uint64 key;
-};
+} board_t;
 
 // functions
 
@@ -54,6 +51,8 @@ extern bool board_equal        (const board_t * board_1, const board_t * board_2
 
 extern void board_init_list    (board_t * board);
 
+extern int  board_flags        (const board_t * board);
+
 extern bool board_can_play     (const board_t * board);
 extern int  board_mobility     (const board_t * board);
 
