@@ -24,8 +24,6 @@
 
 static const bool UseDebug = FALSE;
 
-#define StringSize ((int)4096)
-
 // variables
 
 uci_t Uci[1];
@@ -153,7 +151,7 @@ void uci_open(uci_t * uci, engine_t * engine) {
       // Handle the case that the engine is really a WB engine somewhat gracefully.
       if((strstr(string,"Illegal") || strstr(string,"Error"))
          &&strstr(string,"uci")){
-          my_fatal("uci_open(): Not an UCI engine.\n");
+          my_fatal("uci_open(): Not a UCI engine.\n");
       }
       event = uci_parse(uci,string);
    } while (!engine_eof(Engine) && (event & EVENT_UCI) == 0);
@@ -359,7 +357,7 @@ int uci_parse(uci_t * uci, const char string[]) {
             uci->searching = FALSE;
             uci->pending_nb--;
 
-            event = parse_bestmove(uci,argument); // updates uci->best_move and uci->ponder_move
+            event = parse_bestmove(uci,argument); // updates uci->best_move, uci->ponder_move 
 
          } else {
 
@@ -435,10 +433,14 @@ static int parse_bestmove(uci_t * uci, const char string[]) {
 
    // bestmove
 
+   uci->bestmove[0]='\0';
    if (!parse_get_string(parse,argument,StringSize)) {
+       strcpy(uci->bestmove,"nomove");
        return EVENT_ILLEGAL_MOVE;
 //      my_fatal("parse_bestmove(): missing argument\n");
    }
+   strncpy(uci->bestmove,argument,UciStringSize);
+   uci->bestmove[UciStringSize-1]='\0';
 
    uci->best_move = move_from_can(argument,uci->board);
    if (uci->best_move == MoveNone) {
@@ -470,6 +472,7 @@ static int parse_bestmove(uci_t * uci, const char string[]) {
          move_do(board,uci->best_move);
 
          uci->ponder_move = move_from_can(argument,board);
+
          // if (uci->ponder_move == MoveNone) my_fatal("parse_bestmove(): not a move \"%s\"\n",argument);
 
          ASSERT(uci->ponder_move!=MoveNone);
@@ -667,7 +670,6 @@ static int parse_info(uci_t * uci, const char string[]) {
       } else if (my_string_equal(option,"pv")) {
 
          ASSERT(!my_string_empty(argument));
-
          line_from_can(uci->pv,uci->board,argument,LineSize);
          event |= EVENT_PV;
 
